@@ -1,5 +1,5 @@
 #!/bin/bash
-# Copyright 2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -40,5 +40,5 @@ GOOS=${TARGET_GOOS:-} GOARCH=${TARGET_GOARCH:-} CGO_ENABLED=0 \
        	-a \
        	-ldflags "-buildid= -s ${version_ldflags}" \
        	-trimpath \
-       	-o ../$1/docker-credential-ecr-login \
+       	-o $1/docker-credential-ecr-login \
 	./cli/docker-credential-ecr-login
